@@ -256,7 +256,7 @@ function package:_init ()
   if SILE.typesetter then
     self:bidiEnableTypesetter(SILE.typesetter)
   end
-  self:bidiEnableTypesetter(SILE.defaultTypesetter)
+  self:bidiEnableTypesetter(SILE.typesetters.base)
 end
 
 function package:registerCommands ()
@@ -297,12 +297,12 @@ end
 
 package.documentation = [[
 \begin{document}
-Scripts like the Latin alphabet you are currently reading are normally written left to right; however, some scripts, such as Arabic and Hebrew, are written right to left.
+Scripts like the Latin alphabet you are currently reading are normally written left to right (LTR); however, some scripts, such as Arabic and Hebrew, are written right to left (RTL).
 The \autodoc:package{bidi} package, which is loaded by default, provides SILE with the ability to correctly typeset right-to-left text and also documents which mix right-to-left and left-to-right typesetting.
 Because it is loaded by default, you can use both LTR and RTL text within a paragraph and SILE will ensure that the output characters appear in the correct order.
 
 The \autodoc:package{bidi} package provides two commands, \autodoc:command{\thisframeLTR} and \autodoc:command{\thisframeRTL}, which set the default text direction for the current frame.
-That is, if you tell SILE that a frame is RTL, the text will start in the right margin and proceed leftward.
+If you tell SILE that a frame is RTL, the text will start in the right margin and proceed leftward.
 It also provides the commands \autodoc:command{\bidi-off} and \autodoc:command{\bidi-on}, which allow you to trade off bidirectional support for a dubious increase in speed.
 \end{document}
 ]]
